==> manage-1.2.39.jar: management/sqls/营收/报表管理/统计类/预收款金额统计表/getbalance.sql <==

select s.f_gasproperties_type,s.f_gasproperties,SUM(f_balance) f_balance,SUM(f_curbalance) f_curbalance 
from(
select 
	f_gasproperties_type,
	f_gasproperties,
	cast(SUM(f_money) as numeric(19, 3))+cast(SUM(f_haircut_money) as numeric(19, 3)) f_balance,
	0 f_curbalance
from(
		select 
			s.f_gasproperties_type,
			s.f_gasproperties,
			0 f_money,
			SUM(s1.f_surplus_gas_max)-SUM(isnull(s2.f_haircut_gas,0)) f_haircut_gas,
			(SUM(s1.f_surplus_gas_max)-SUM(isnull(s2.f_haircut_gas,0)))*1.98 f_haircut_money
		from (
			select 
				f_price_id,
				SUM(f_surplus_gas_max) f_surplus_gas_max
			from(
					select 
						f_price_id,
						f_userinfo_id,
						MIN(f_surplus_gas)+SUM(f_haircut_gas) f_surplus_gas_max
					from 
						V_handplan 
					where 
						f_meter_state='已抄表'	and		
						f_haircut_gas!=0 
					group by f_price_id,f_userinfo_id
			) g group by f_price_id
		) s1 left join (
			select 
					f_price_id,
					SUM(f_haircut_gas) f_haircut_gas
				from 
					V_handplan 
				where 
					 f_hand_date<dateadd(month,-1,'{startDate}') and
					f_meter_state='已抄表'	and		
					f_haircut_gas!=0 
				group by f_price_id
		) s2 on s1.f_price_id=s2.f_price_id
		left join (select * from t_stairprice where f_state='有效') s 
		on s1.f_price_id=s.f_price_id
		group by s.f_gasproperties_type,s.f_gasproperties
	union all
		select 
			 f_gasproperties_type,
			 f_gasproperties,
			 sum(f_balance) f_money,
			 0 f_haircut_gas,
			 0 f_haircut_money
		from 
			(
		  select s.f_price_id,
			     s.f_userinfo_id,
			     (s.f_curbalance) f_balance from (
			select 	 
			         s1.id,
			         s1.f_price_id,
			         s1.f_userinfo_id,
			         s1.f_curbalance from (
			select 
				f_userinfo_id,max(f_delivery_date) f_delivery_date
			from t_sellinggas 
			where  f_delivery_date<'{startDate}' 
					and  f_charge_state='有效'
			group by f_userinfo_id
			) s
			left join t_sellinggas s1 
			on s.f_userinfo_id=s1.f_userinfo_id and s.f_delivery_date=s1.f_delivery_date 
	      ) s
	      left join
	      (select f_sell_id,SUM(f_oughtfee) f_oughtfee from V_handplan where 
	      f_meter_state='已抄表' and	f_whether_pay='是'
	      and f_hand_date<dateadd(month,-1,'{startDate}') 
	      group by f_sell_id
	      ) h on s.id=h.f_sell_id
		) t
        left join (select * from t_stairprice where f_state='有效') s2 
	    on t.f_price_id=s2.f_price_id			
		group by s2.f_gasproperties_type,s2.f_gasproperties
) s 
group by 	f_gasproperties_type,f_gasproperties

UNION ALL
	select 
		f_gasproperties_type,
		f_gasproperties,
		0 f_balance,
		cast(SUM(f_money) as numeric(19, 3))+cast(SUM(f_haircut_money) as numeric(19, 3)) f_curbalance
	from(
			select 
				s.f_gasproperties_type,
				s.f_gasproperties,
				0 f_money,
				SUM(s1.f_surplus_gas_max)-SUM(isnull(s2.f_haircut_gas,0)) f_haircut_gas,
				(SUM(s1.f_surplus_gas_max)-SUM(isnull(s2.f_haircut_gas,0)))*1.98 f_haircut_money
			from (
				select 
					f_price_id,
					SUM(f_surplus_gas_max) f_surplus_gas_max
				from(
						select 
							f_price_id,
							f_userinfo_id,
							MIN(f_surplus_gas)+SUM(f_haircut_gas) f_surplus_gas_max
						from
							V_handplan 
						where 
							f_meter_state='已抄表'  and	
							f_haircut_gas!=0 
						group by f_price_id,f_userinfo_id
				) g group by f_price_id
			) s1 left join (
				select 
						f_price_id,
						SUM(f_haircut_gas) f_haircut_gas
					from 
						V_handplan 
					where 
						 f_hand_date<=DATEADD(ms,-3,DATEADD(mm, DATEDIFF(m,0,'{endDate}'), 0)) and
						f_meter_state='已抄表' and	
						f_haircut_gas!=0 
					group by f_price_id
			) s2 on s1.f_price_id=s2.f_price_id
			left join (select * from t_stairprice where f_state='有效') s 
			on s1.f_price_id=s.f_price_id
			group by s.f_gasproperties_type,s.f_gasproperties
		union all
		 select 
				 s2.f_gasproperties_type,
				 s2.f_gasproperties,
				 sum(f_money) f_money,
				 0 f_haircut_gas,
				 0 f_haircut_money
		 from (
		  select 
				 f_price_id,
				 (f_curbalance+isnull(f_oughtfee,0)) f_money
			from 
				(
				 
				select 
				       s1.f_price_id,
				       s1.f_curbalance,
				       s1.id  from(
				select 
					f_userinfo_id,max(f_delivery_date) f_delivery_date
				from t_sellinggas 
				where  f_delivery_date<='{endDate}' 
						and  f_charge_state='有效'
				group by f_userinfo_id
				) s
				left join t_sellinggas s1 
				on s.f_userinfo_id=s1.f_userinfo_id and 
				s.f_delivery_date=s1.f_delivery_date 
				) s
				left join
				  (select f_sell_id,SUM(f_oughtfee) f_oughtfee from V_handplan where 
	               f_meter_state='已抄表' and	f_whether_pay='是'
	               and f_hand_date>='{startDate}' 
	               group by f_sell_id
	            ) h on s.id=h.f_sell_id
	          ) t
		     left join (select * from t_stairprice where f_state='有效') s2 
		    on t.f_price_id=s2.f_price_id
			group by s2.f_gasproperties_type,s2.f_gasproperties
	) s group by 	f_gasproperties_type,f_gasproperties
) s group by 	 s.f_gasproperties_type,s.f_gasproperties

==> manage-3.1.0-46.jar: management/sqls/营收/报表管理/统计类/预收款金额统计表/getbalance.sql <==

select s.f_gasproperties_type,s.f_gasproperties,SUM(f_balance) f_balance,SUM(f_curbalance) f_curbalance 
from(
select 
	f_gasproperties_type,
	f_gasproperties,
	cast(SUM(f_money) as numeric(19, 3))+cast(SUM(f_haircut_money) as numeric(19, 3)) f_balance,
	0 f_curbalance
from(
		select 
			s.f_gasproperties_type,
			s.f_gasproperties,
			0 f_money,
			SUM(s1.f_surplus_gas_max)-SUM(isnull(s2.f_haircut_gas,0)) f_haircut_gas,
			(SUM(s1.f_surplus_gas_max)-SUM(isnull(s2.f_haircut_gas,0)))*1.98 f_haircut_money
		from (
			select 
				f_price_id,
				SUM(f_surplus_gas_max) f_surplus_gas_max
			from(
					select 
						f_price_id,
						f_userinfo_id,
						MIN(f_surplus_gas)+SUM(f_haircut_gas) f_surplus_gas_max
					from 
						V_handplan 
					where 
						f_meter_state='已抄表'	and		
						f_haircut_gas!=0 
					group by f_price_id,f_userinfo_id
			) g group by f_price_id
		) s1 left join (
			select 
					f_price_id,
					SUM(f_haircut_gas) f_haircut_gas
				from 
					V_handplan 
				where 
					 f_hand_date<dateadd(month,-1,'{startDate}') and
					f_meter_state='已抄表'	and		
					f_haircut_gas!=0 
				group by f_price_id
		) s2 on s1.f_price_id=s2.f_price_id
		left join (select * from t_stairprice where f_state='有效') s 
		on s1.f_price_id=s.f_price_id
		group by s.f_gasproperties_type,s.f_gasproperties
	union all
		select 
			 f_gasproperties_type,
			 f_gasproperties,
			 sum(f_balance) f_money,
			 0 f_haircut_gas,
			 0 f_haircut_money
		from 
			(
		  select s.f_price_id,
			     s.f_userinfo_id,
			     (s.f_curbalance) f_balance from (
			select 	 
			         s1.id,
			         s1.f_price_id,
			         s1.f_userinfo_id,
			         s1.f_curbalance from (
			select 
				f_userinfo_id,max(f_operate_date) f_operate_date
			from t_sellinggas 
			where  f_operate_date<'{startDate}'
					and  f_state='有效'
			group by f_userinfo_id
			) s
			left join t_sellinggas s1 
			on s.f_userinfo_id=s1.f_userinfo_id and s.f_operate_date=s1.f_operate_date
	      ) s
	      left join
	      (select f_sell_id,SUM(f_oughtfee) f_oughtfee from V_handplan where 
	      f_meter_state='已抄表' and	f_whether_pay='是'
	      and f_hand_date<dateadd(month,-1,'{startDate}') 
	      group by f_sell_id
	      ) h on s.id=h.f_sell_id
		) t
        left join (select * from t_stairprice where f_state='有效') s2 
	    on t.f_price_id=s2.f_price_id			
		group by s2.f_gasproperties_type,s2.f_gasproperties
) s 
group by 	f_gasproperties_type,f_gasproperties

UNION ALL
	select 
		f_gasproperties_type,
		f_gasproperties,
		0 f_balance,
		cast(SUM(f_money) as numeric(19, 3))+cast(SUM(f_haircut_money) as numeric(19, 3)) f_curbalance
	from(
			select 
				s.f_gasproperties_type,
				s.f_gasproperties,
				0 f_money,
				SUM(s1.f_surplus_gas_max)-SUM(isnull(s2.f_haircut_gas,0)) f_haircut_gas,
				(SUM(s1.f_surplus_gas_max)-SUM(isnull(s2.f_haircut_gas,0)))*1.98 f_haircut_money
			from (
				select 
					f_price_id,
					SUM(f_surplus_gas_max) f_surplus_gas_max
				from(
						select 
							f_price_id,
							f_userinfo_id,
							MIN(f_surplus_gas)+SUM(f_haircut_gas) f_surplus_gas_max
						from
							V_handplan 
						where 
							f_meter_state='已抄表'  and	
							f_haircut_gas!=0 
						group by f_price_id,f_userinfo_id
				) g group by f_price_id
			) s1 left join (
				select 
						f_price_id,
						SUM(f_haircut_gas) f_haircut_gas
					from 
						V_handplan 
					where 
						 f_hand_date<=DATEADD(ms,-3,DATEADD(mm, DATEDIFF(m,0,'{endDate}'), 0)) and
						f_meter_state='已抄表' and	
						f_haircut_gas!=0 
					group by f_price_id
			) s2 on s1.f_price_id=s2.f_price_id
			left join (select * from t_stairprice where f_state='有效') s 
			on s1.f_price_id=s.f_price_id
			group by s.f_gasproperties_type,s.f_gasproperties
		union all
		 select 
				 s2.f_gasproperties_type,
				 s2.f_gasproperties,
				 sum(f_money) f_money,
				 0 f_haircut_gas,
				 0 f_haircut_money
		 from (
		  select 
				 f_price_id,
				 (f_curbalance+isnull(f_oughtfee,0)) f_money
			from 
				(
				 
				select 
				       s1.f_price_id,
				       s1.f_curbalance,
				       s1.id  from(
				select 
					f_userinfo_id,max(f_operate_date) f_operate_date
				from t_sellinggas 
				where  f_operate_date<='{endDate}'
						and  f_state='有效'
				group by f_userinfo_id
				) s
				left join t_sellinggas s1 
				on s.f_userinfo_id=s1.f_userinfo_id and 
				s.f_operate_date=s1.f_operate_date
				) s
				left join
				  (select f_sell_id,SUM(f_oughtfee) f_oughtfee from V_handplan where 
	               f_meter_state='已抄表' and	f_whether_pay='是'
	               and f_hand_date>='{startDate}' 
	               group by f_sell_id
	            ) h on s.id=h.f_sell_id
	          ) t
		     left join (select * from t_stairprice where f_state='有效') s2 
		    on t.f_price_id=s2.f_price_id
			group by s2.f_gasproperties_type,s2.f_gasproperties
	) s group by 	f_gasproperties_type,f_gasproperties
) s group by 	 s.f_gasproperties_type,s.f_gasproperties
